# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/metric_responses.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import response_types_pb2 as t2iapi_dot_response__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$t2iapi/metric/metric_responses.proto\x12\rt2iapi.metric\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/response_types.proto\"R\n\x1aSetOverOrUnderflowResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\r\n\x05value\x18\x02 \x01(\t\"R\n\x17\x43\x61librateMetricResponse\x12\'\n\x08response\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x0e\n\x06values\x18\x02 \x03(\t\"\x88\x01\n\x13MetricValueResponse\x12%\n\x06result\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\r\n\x05value\x18\x02 \x01(\t\x12\x12\n\nstep_width\x18\x03 \x01(\t\x12\'\n\x04unit\x18\x04 \x01(\x0b\x32\x19.t2iapi.PartialCodedValueB4\n!com.draeger.medical.t2iapi.metricB\x0fMetricResponsesb\x06proto3')



_SETOVERORUNDERFLOWRESPONSE = DESCRIPTOR.message_types_by_name['SetOverOrUnderflowResponse']
_CALIBRATEMETRICRESPONSE = DESCRIPTOR.message_types_by_name['CalibrateMetricResponse']
_METRICVALUERESPONSE = DESCRIPTOR.message_types_by_name['MetricValueResponse']
SetOverOrUnderflowResponse = _reflection.GeneratedProtocolMessageType('SetOverOrUnderflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETOVERORUNDERFLOWRESPONSE,
  '__module__' : 't2iapi.metric.metric_responses_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetOverOrUnderflowResponse)
  })
_sym_db.RegisterMessage(SetOverOrUnderflowResponse)

CalibrateMetricResponse = _reflection.GeneratedProtocolMessageType('CalibrateMetricResponse', (_message.Message,), {
  'DESCRIPTOR' : _CALIBRATEMETRICRESPONSE,
  '__module__' : 't2iapi.metric.metric_responses_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.CalibrateMetricResponse)
  })
_sym_db.RegisterMessage(CalibrateMetricResponse)

MetricValueResponse = _reflection.GeneratedProtocolMessageType('MetricValueResponse', (_message.Message,), {
  'DESCRIPTOR' : _METRICVALUERESPONSE,
  '__module__' : 't2iapi.metric.metric_responses_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.MetricValueResponse)
  })
_sym_db.RegisterMessage(MetricValueResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\017MetricResponses'
  _SETOVERORUNDERFLOWRESPONSE._serialized_start=114
  _SETOVERORUNDERFLOWRESPONSE._serialized_end=196
  _CALIBRATEMETRICRESPONSE._serialized_start=198
  _CALIBRATEMETRICRESPONSE._serialized_end=280
  _METRICVALUERESPONSE._serialized_start=283
  _METRICVALUERESPONSE._serialized_end=419
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import basic_requests_pb2 as t2iapi_dot_basic__requests__pb2
from t2iapi.metric import metric_requests_pb2 as t2iapi_dot_metric_dot_metric__requests__pb2
from t2iapi.metric import metric_responses_pb2 as t2iapi_dot_metric_dot_metric__responses__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bt2iapi/metric/service.proto\x12\rt2iapi.metric\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/basic_requests.proto\x1a#t2iapi/metric/metric_requests.proto\x1a$t2iapi/metric/metric_responses.proto2\x9d\t\n\rMetricService\x12[\n\x0bSetOverflow\x12!.t2iapi.metric.SetOverflowRequest\x1a).t2iapi.metric.SetOverOrUnderflowResponse\x12]\n\x0cSetUnderflow\x12\".t2iapi.metric.SetUnderflowRequest\x1a).t2iapi.metric.SetOverOrUnderflowResponse\x12\x61\n\x18SetMetricQualityValidity\x12..t2iapi.metric.SetMetricQualityValidityRequest\x1a\x15.t2iapi.BasicResponse\x12?\n\nSetNoValue\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12L\n\x17SetUserConfirmableValue\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12\x44\n\x0fSetInvalidValue\x12\x1a.t2iapi.BasicHandleRequest\x1a\x15.t2iapi.BasicResponse\x12U\n\x0f\x43\x61librateMetric\x12\x1a.t2iapi.BasicHandleRequest\x1a&.t2iapi.metric.CalibrateMetricResponse\x12k\n\"SetMetricValuesWithQualityValidity\x12..t2iapi.metric.SetMetricQualityValidityRequest\x1a\x15.t2iapi.BasicResponse\x12m\n\x1eSetMetricValuesWithQualityMode\x12\x34.t2iapi.metric.SetMetricValuesWithQualityModeRequest\x1a\x15.t2iapi.BasicResponse\x12]\n\x16SetMetricValuesInRange\x12,.t2iapi.metric.SetMetricValuesInRangeRequest\x1a\x15.t2iapi.BasicResponse\x12P\n\x0eGetMetricValue\x12\x1a.t2iapi.BasicHandleRequest\x1a\".t2iapi.metric.MetricValueResponse\x12\x63\n\x19\x43hangeOperationModeStatus\x12/.t2iapi.metric.ChangeOperationModeStatusRequest\x1a\x15.t2iapi.BasicResponse\x12O\n\x0fSetMetricStatus\x12%.t2iapi.metric.SetMetricStatusRequest\x1a\x15.t2iapi.BasicResponseB5\n!com.draeger.medical.t2iapi.metricB\x10MetricApiServiceb\x06proto3')



_METRICSERVICE = DESCRIPTOR.services_by_name['MetricService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\020MetricApiService'
  _METRICSERVICE._serialized_start=181
  _METRICSERVICE._serialized_end=1362
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/device/device_requests.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.device import types_pb2 as t2iapi_dot_device_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#t2iapi/device/device_requests.proto\x12\rt2iapi.device\x1a\x19t2iapi/device/types.proto\"A\n\x14TriggerReportRequest\x12)\n\x06report\x18\x01 \x01(\x0e\x32\x19.t2iapi.device.ReportType\"N\n\x1dSetDeviceOperatingModeRequest\x12-\n\x04mode\x18\x01 \x01(\x0e\x32\x1f.t2iapi.device.MdsOperatingMode\"U\n\x1fGenerateElementsInStatesRequest\x12\x32\n\rrelative_path\x18\x01 \x03(\x0b\x32\x1b.t2iapi.device.ExpandedName\"&\n\x12SetLanguageRequest\x12\x10\n\x08language\x18\x01 \x01(\t\"7\n\x1b\x43hangeMdibSequenceIdRequest\x12\x18\n\x10\x64\x65scriptive_name\x18\x01 \x01(\tB3\n!com.draeger.medical.t2iapi.deviceB\x0e\x44\x65viceRequestsb\x06proto3')



_TRIGGERREPORTREQUEST = DESCRIPTOR.message_types_by_name['TriggerReportRequest']
_SETDEVICEOPERATINGMODEREQUEST = DESCRIPTOR.message_types_by_name['SetDeviceOperatingModeRequest']
_GENERATEELEMENTSINSTATESREQUEST = DESCRIPTOR.message_types_by_name['GenerateElementsInStatesRequest']
_SETLANGUAGEREQUEST = DESCRIPTOR.message_types_by_name['SetLanguageRequest']
_CHANGEMDIBSEQUENCEIDREQUEST = DESCRIPTOR.message_types_by_name['ChangeMdibSequenceIdRequest']
TriggerReportRequest = _reflection.GeneratedProtocolMessageType('TriggerReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERREPORTREQUEST,
  '__module__' : 't2iapi.device.device_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.device.TriggerReportRequest)
  })
_sym_db.RegisterMessage(TriggerReportRequest)

SetDeviceOperatingModeRequest = _reflection.GeneratedProtocolMessageType('SetDeviceOperatingModeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDEVICEOPERATINGMODEREQUEST,
  '__module__' : 't2iapi.device.device_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.device.SetDeviceOperatingModeRequest)
  })
_sym_db.RegisterMessage(SetDeviceOperatingModeRequest)

GenerateElementsInStatesRequest = _reflection.GeneratedProtocolMessageType('GenerateElementsInStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEELEMENTSINSTATESREQUEST,
  '__module__' : 't2iapi.device.device_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.device.GenerateElementsInStatesRequest)
  })
_sym_db.RegisterMessage(GenerateElementsInStatesRequest)

SetLanguageRequest = _reflection.GeneratedProtocolMessageType('SetLanguageRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETLANGUAGEREQUEST,
  '__module__' : 't2iapi.device.device_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.device.SetLanguageRequest)
  })
_sym_db.RegisterMessage(SetLanguageRequest)

ChangeMdibSequenceIdRequest = _reflection.GeneratedProtocolMessageType('ChangeMdibSequenceIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEMDIBSEQUENCEIDREQUEST,
  '__module__' : 't2iapi.device.device_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.device.ChangeMdibSequenceIdRequest)
  })
_sym_db.RegisterMessage(ChangeMdibSequenceIdRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.deviceB\016DeviceRequests'
  _TRIGGERREPORTREQUEST._serialized_start=81
  _TRIGGERREPORTREQUEST._serialized_end=146
  _SETDEVICEOPERATINGMODEREQUEST._serialized_start=148
  _SETDEVICEOPERATINGMODEREQUEST._serialized_end=226
  _GENERATEELEMENTSINSTATESREQUEST._serialized_start=228
  _GENERATEELEMENTSINSTATESREQUEST._serialized_end=313
  _SETLANGUAGEREQUEST._serialized_start=315
  _SETLANGUAGEREQUEST._serialized_end=353
  _CHANGEMDIBSEQUENCEIDREQUEST._serialized_start=355
  _CHANGEMDIBSEQUENCEIDREQUEST._serialized_end=410
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/metric_requests.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.metric import types_pb2 as t2iapi_dot_metric_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#t2iapi/metric/metric_requests.proto\x12\rt2iapi.metric\x1a\x19t2iapi/metric/types.proto\"9\n\x12SetOverflowRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x13\n\x0bupper_bound\x18\x02 \x01(\t\":\n\x13SetUnderflowRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x13\n\x0blower_bound\x18\x02 \x01(\t\"g\n\x1fSetMetricQualityValidityRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x34\n\x08validity\x18\x02 \x01(\x0e\x32\".t2iapi.metric.MeasurementValidity\"d\n%SetMetricValuesWithQualityModeRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12+\n\x04mode\x18\x02 \x01(\x0e\x32\x1d.t2iapi.metric.GenerationMode\"M\n\x1dSetMetricValuesInRangeRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\r\n\x05lower\x18\x02 \x01(\t\x12\r\n\x05upper\x18\x03 \x01(\t\"u\n ChangeOperationModeStatusRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x41\n\x15operation_mode_status\x18\x02 \x01(\x0e\x32\".t2iapi.metric.OperationModeStatus\"U\n\x16SetMetricStatusRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.t2iapi.metric.MetricStatusB3\n!com.draeger.medical.t2iapi.metricB\x0eMetricRequestsb\x06proto3')



_SETOVERFLOWREQUEST = DESCRIPTOR.message_types_by_name['SetOverflowRequest']
_SETUNDERFLOWREQUEST = DESCRIPTOR.message_types_by_name['SetUnderflowRequest']
_SETMETRICQUALITYVALIDITYREQUEST = DESCRIPTOR.message_types_by_name['SetMetricQualityValidityRequest']
_SETMETRICVALUESWITHQUALITYMODEREQUEST = DESCRIPTOR.message_types_by_name['SetMetricValuesWithQualityModeRequest']
_SETMETRICVALUESINRANGEREQUEST = DESCRIPTOR.message_types_by_name['SetMetricValuesInRangeRequest']
_CHANGEOPERATIONMODESTATUSREQUEST = DESCRIPTOR.message_types_by_name['ChangeOperationModeStatusRequest']
_SETMETRICSTATUSREQUEST = DESCRIPTOR.message_types_by_name['SetMetricStatusRequest']
SetOverflowRequest = _reflection.GeneratedProtocolMessageType('SetOverflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETOVERFLOWREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetOverflowRequest)
  })
_sym_db.RegisterMessage(SetOverflowRequest)

SetUnderflowRequest = _reflection.GeneratedProtocolMessageType('SetUnderflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETUNDERFLOWREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetUnderflowRequest)
  })
_sym_db.RegisterMessage(SetUnderflowRequest)

SetMetricQualityValidityRequest = _reflection.GeneratedProtocolMessageType('SetMetricQualityValidityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMETRICQUALITYVALIDITYREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetMetricQualityValidityRequest)
  })
_sym_db.RegisterMessage(SetMetricQualityValidityRequest)

SetMetricValuesWithQualityModeRequest = _reflection.GeneratedProtocolMessageType('SetMetricValuesWithQualityModeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMETRICVALUESWITHQUALITYMODEREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetMetricValuesWithQualityModeRequest)
  })
_sym_db.RegisterMessage(SetMetricValuesWithQualityModeRequest)

SetMetricValuesInRangeRequest = _reflection.GeneratedProtocolMessageType('SetMetricValuesInRangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMETRICVALUESINRANGEREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetMetricValuesInRangeRequest)
  })
_sym_db.RegisterMessage(SetMetricValuesInRangeRequest)

ChangeOperationModeStatusRequest = _reflection.GeneratedProtocolMessageType('ChangeOperationModeStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEOPERATIONMODESTATUSREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.ChangeOperationModeStatusRequest)
  })
_sym_db.RegisterMessage(ChangeOperationModeStatusRequest)

SetMetricStatusRequest = _reflection.GeneratedProtocolMessageType('SetMetricStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMETRICSTATUSREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetMetricStatusRequest)
  })
_sym_db.RegisterMessage(SetMetricStatusRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\016MetricRequests'
  _SETOVERFLOWREQUEST._serialized_start=81
  _SETOVERFLOWREQUEST._serialized_end=138
  _SETUNDERFLOWREQUEST._serialized_start=140
  _SETUNDERFLOWREQUEST._serialized_end=198
  _SETMETRICQUALITYVALIDITYREQUEST._serialized_start=200
  _SETMETRICQUALITYVALIDITYREQUEST._serialized_end=303
  _SETMETRICVALUESWITHQUALITYMODEREQUEST._serialized_start=305
  _SETMETRICVALUESWITHQUALITYMODEREQUEST._serialized_end=405
  _SETMETRICVALUESINRANGEREQUEST._serialized_start=407
  _SETMETRICVALUESINRANGEREQUEST._serialized_end=484
  _CHANGEOPERATIONMODESTATUSREQUEST._serialized_start=486
  _CHANGEOPERATIONMODESTATUSREQUEST._serialized_end=603
  _SETMETRICSTATUSREQUEST._serialized_start=605
  _SETMETRICSTATUSREQUEST._serialized_end=690
# @@protoc_insertion_point(module_scope)
